==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/CascadegrantrevokeaccessversiontrackerRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Cascadegrantrevokeaccessversiontracker;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.CascadegrantrevokeaccessrecordstrackerCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class CascadegrantrevokeaccessversiontrackerRequest extends EntityRequest<Cascadegrantrevokeaccessversiontracker> {

    public CascadegrantrevokeaccessversiontrackerRequest(ContextPath contextPath, Optional<Object> value) {
        super(Cascadegrantrevokeaccessversiontracker.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SyncerrorCollectionRequest cascadegrantrevokeaccessversiontracker_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest cascadegrantrevokeaccessversiontracker_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest cascadegrantrevokeaccessversiontracker_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest cascadegrantrevokeaccessversiontracker_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest cascadegrantrevokeaccessversiontracker_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest cascadegrantrevokeaccessversiontracker_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest cascadegrantrevokeaccessversiontracker_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest cascadegrantrevokeaccessversiontracker_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public CascadegrantrevokeaccessrecordstrackerCollectionRequest syncTrackerIdLookup() {
        return new CascadegrantrevokeaccessrecordstrackerCollectionRequest(
                        contextPath.addSegment("SyncTrackerIdLookup"), Optional.empty());
    }

    public CascadegrantrevokeaccessrecordstrackerRequest syncTrackerIdLookup(String cascadegrantrevokeaccessrecordstrackerid) {
        return new CascadegrantrevokeaccessrecordstrackerRequest(contextPath.addSegment("SyncTrackerIdLookup").addKeys(new NameValue(cascadegrantrevokeaccessrecordstrackerid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/request/CascadegrantrevokeaccessversiontrackerRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Cascadegrantrevokeaccessversiontracker;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.CascadegrantrevokeaccessrecordstrackerCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class CascadegrantrevokeaccessversiontrackerRequest extends EntityRequest<Cascadegrantrevokeaccessversiontracker> {

    public CascadegrantrevokeaccessversiontrackerRequest(ContextPath contextPath, Optional<Object> value) {
        super(Cascadegrantrevokeaccessversiontracker.class, contextPath, value);
    }

    public SyncerrorCollectionRequest cascadegrantrevokeaccessversiontracker_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest cascadegrantrevokeaccessversiontracker_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest cascadegrantrevokeaccessversiontracker_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest cascadegrantrevokeaccessversiontracker_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest cascadegrantrevokeaccessversiontracker_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest cascadegrantrevokeaccessversiontracker_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest cascadegrantrevokeaccessversiontracker_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest cascadegrantrevokeaccessversiontracker_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("cascadegrantrevokeaccessversiontracker_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public CascadegrantrevokeaccessrecordstrackerCollectionRequest syncTrackerIdLookup() {
        return new CascadegrantrevokeaccessrecordstrackerCollectionRequest(
                        contextPath.addSegment("SyncTrackerIdLookup"), Optional.empty());
    }

    public CascadegrantrevokeaccessrecordstrackerRequest syncTrackerIdLookup(String cascadegrantrevokeaccessrecordstrackerid) {
        return new CascadegrantrevokeaccessrecordstrackerRequest(contextPath.addSegment("SyncTrackerIdLookup").addKeys(new NameValue(cascadegrantrevokeaccessrecordstrackerid.toString())), Optional.empty());
    }

}
